package Data::Object::Func::Scalar;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Scalar

=cut

=head1 ABSTRACT

Functions for ScalarRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Scalar;

=cut

=head1 DESCRIPTION

Data::Object::Func::Scalar is an abstract base class for function classes in
the Data::Object::Func::Scalar space.

=cut
